==> haskell-gtk2hs-buildtools-0.13.10.0-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gtk2hs-buildtools
version:              0.13.10.0
visibility:           public
id:                   gtk2hs-buildtools-0.13.10.0-I1PFsKOcjZ2JMEfvxbGHsq
key:                  gtk2hs-buildtools-0.13.10.0-I1PFsKOcjZ2JMEfvxbGHsq
license:              GPL-2.0-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-devel@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts, Manuel Chakravaty
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:
    Tools to build the Gtk2Hs suite of User Interface libraries.

description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.

category:             Development
abi:                  fb723877cb269991e06185a10001c7ea
exposed:              True
exposed-modules:      Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules:
    Paths_gtk2hs_buildtools BaseVersion Config Errors Binary DLists
    FastMutInt FileOps FNameOps Map Position Set UNames CIO State
    StateBase StateTrans Attributes Idents NameSpaces Lexers C CAST
    CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty CTokens
    CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader C2HSState
    Switches C2HSConfig Version

import-dirs:          /usr/lib/ghc-9.2.8/site-local/gtk2hs-buildtools-0.13.10.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/gtk2hs-buildtools-0.13.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk2hs-buildtools
hs-libraries:         HSgtk2hs-buildtools-0.13.10.0-I1PFsKOcjZ2JMEfvxbGHsq
depends:
    Cabal-3.6.3.0 array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2
    hashtables-1.3.1-19pwafFiCaCEjS0N0RfZKT pretty-1.1.3.6
    process-1.6.16.0 random-1.2.1.2-BXSdRxlC6g4I8lxfKC5NFh

haddock-interfaces:
    /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock

haddock-html:         /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gtk2hs-buildtools-0.13.12.0-6.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-gtk2hs-buildtools.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gtk2hs-buildtools
version:              0.13.12.0
visibility:           public
id:                   gtk2hs-buildtools-0.13.12.0-7LDQcnA3OJoKtBexe0azPD
key:                  gtk2hs-buildtools-0.13.12.0-7LDQcnA3OJoKtBexe0azPD
license:              GPL-2.0-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-devel@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts, Manuel Chakravaty
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:
    Tools to build the Gtk2Hs suite of User Interface libraries.

description:
    This package provides a set of helper programs necessary to
    build the Gtk2Hs suite of libraries. These tools include
    a modified c2hs binding tool that is used to generate
    FFI declarations, a tool to build a type hierarchy that
    mirrors the C type hierarchy of GObjects found in glib,
    and a generator for signal declarations that are used
    to call back from C to Haskell. These tools are not needed
    to actually run Gtk2Hs programs.

category:             Development
abi:                  f521615ff702f82a97348b8799410c2d
exposed:              True
exposed-modules:      Gtk2HsC2Hs Gtk2HsSetup HookGenerator TypeGen
hidden-modules:
    Paths_gtk2hs_buildtools BaseVersion Config Errors Binary DLists
    FastMutInt FileOps FNameOps Map Position Set UNames CIO State
    StateBase StateTrans Attributes Idents NameSpaces Lexers C CAST
    CAttrs CBuiltin CLexer CNames CParser CParserMonad CPretty CTokens
    CTrav CHS CHSLexer CInfo GBMonad GenBind GenHeader C2HSState
    Switches C2HSConfig Version

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gtk2hs-buildtools-0.13.12.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gtk2hs-buildtools-0.13.12.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gtk2hs-buildtools-0.13.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gtk2hs-buildtools
hs-libraries:         HSgtk2hs-buildtools-0.13.12.0-7LDQcnA3OJoKtBexe0azPD
depends:
    Cabal-3.8.1.0 array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    directory-1.3.7.1 filepath-1.4.2.2
    hashtables-1.3.1-2lIi4A9XzcGEFFrCjsaDCt pretty-1.1.3.6
    process-1.6.18.0 random-1.2.1.2-5Y3bNr2vhgE1UbXPPVLWyj

haddock-interfaces:
    /usr/share/doc/haskell-gtk2hs-buildtools/html/gtk2hs-buildtools.haddock

haddock-html:         /usr/share/doc/haskell-gtk2hs-buildtools/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
